@@ -1,6 +1,6 @@
 # Ordinal regression
 .ordinal_weightit.fit <- function(x, y, weights = NULL, start = NULL, offset = NULL,
-                               link = "logit", hess = TRUE, ...) {
+                                  link = "logit", hess = TRUE, ...) {
   chk::chk_atomic(y)
   chk::chk_numeric(x)
   chk::chk_matrix(x)
@@ -108,7 +108,7 @@
   }
 
   #Ordinal regression LL (cumsum paramaterization)
-  ll <- function(B, X, Y, weights, offset, .cumsum_param = TRUE) {
+  ll <- function(B, X, y, weights, offset, .cumsum_param = TRUE) {
     if (no_x) {
       a <- B
       Xb <- offset
@@ -124,24 +124,32 @@
     }
 
     # Probability of observed outcome
-    p <- get_p(Y, Xb, a)
+    p <- get_p(y, Xb, a)
 
     sum(weights * log(p))
   }
 
+  dots <- list(...)
+
+  control <- list(fnscale = -1, #maximize likelihood; optim() minimizes by default
+                  trace = 0,
+                  maxit = 1e3,
+                  reltol = 1e-12)
+
+  control <- utils::modifyList(control,
+                               dots[intersect(names(dots), c("trace", "maxit", "reltol", "ndeps", "REPORT"))])
+
   # Estimate using cumsum parameterization to get estimates
   out0 <- optim(par = start,
                 ll,
                 X = x_,
-                Y = y_,
+                y = y_,
                 weights = weights,
                 offset = offset,
                 .cumsum_param = TRUE,
                 method = "BFGS",
                 hessian = FALSE,
-                control = list(fnscale = -1,
-                               maxit = 1e3,
-                               reltol = 1e-14))
+                control = control)
 
   theta0 <- out0$par
 
@@ -157,8 +165,8 @@
   }
 
   # Psi function and gradient using natural parameterization
-  psi <- function(B, X, Y, weights, offset = NULL) {
-    if (is_null(offset)) offset <- rep.int(0, length(Y))
+  psi <- function(B, X, y, weights, offset = NULL) {
+    if (is_null(offset)) offset <- rep.int(0, length(y))
 
     if (no_x) {
       a <- B
@@ -170,10 +178,10 @@
       Xb <- offset + drop(X %*% b)
     }
 
-    pp <- get_p(Y, Xb, a)
+    pp <- get_p(y, Xb, a)
 
-    gj <- .mu.eta(c(a, Inf)[Y] - Xb)
-    gj1 <- .mu.eta(c(-Inf, a)[Y] - Xb)
+    gj <- .mu.eta(c(a, Inf)[y] - Xb)
+    gj1 <- .mu.eta(c(-Inf, a)[y] - Xb)
 
     .psi_a <- gj * y_mat0 - gj1 * y_mat1
 
@@ -189,8 +197,8 @@
     out
   }
 
-  gr <- function(B, X, Y, weights, offset = NULL) {
-    colSums(psi(B, X, Y, weights, offset))
+  gr <- function(B, X, y, weights, offset = NULL) {
+    colSums(psi(B, X, y, weights, offset))
   }
 
   hessian <- NULL
@@ -199,7 +207,7 @@
     hessian <- try(optimHess(par = theta0,
                              function(...) ll(..., .cumsum_param = FALSE),
                              X = x_,
-                             Y = y_,
+                             y = y_,
                              weights = weights,
                              offset = offset,
                              gr = gr,
@@ -210,7 +218,7 @@
     if (null_or_error(hessian)) {
       hessian <- .gradient(gr, theta0,
                            X = x_,
-                           Y = y_,
+                           y = y_,
                            weights = weights,
                            offset = offset)
     }
@@ -224,7 +232,7 @@
 
   theta <- theta0
 
-  grad <- psi(theta, X = x_, Y = y_,
+  grad <- psi(theta, X = x_, y = y_,
               weights = weights, offset = offset)
 
   # Get predicted probabilities for all units for all categories,
@@ -285,7 +293,7 @@
 }
 
 .ordinal_weightit <- function(formula, data, link = "logit", weights, subset, start = NULL, na.action,
-                           hess = TRUE, model = TRUE, x = FALSE, y = TRUE, contrasts = NULL, ...) {
+                              hess = TRUE, model = TRUE, x = FALSE, y = TRUE, contrasts = NULL, ...) {
   cal <- match.call()
 
   chk::chk_flag(hess)
@@ -346,3 +354,135 @@
          contrasts = attr(X, "contrasts"), xlevels = .getXlevels(mt, mf)))
 }
 
+.get_hess_ordinal <- function(fit) {
+  x <- if_null_then(fit[["x"]], model.matrix(fit))
+  y <- if_null_then(fit[["y"]], model.response(model.frame(fit)))
+  family <- fit[["family"]]
+  weights <- weights(fit)
+  offset <- fit$offset
+  coefs <- coef(fit)
+
+  .linkinv <- family$linkinv
+  .mu.eta <- family$mu.eta
+
+  y <- droplevels(as.factor(y))
+  n <- length(y)
+
+  if (is_null(weights)) weights <- rep.int(1, n)
+
+  if (is.null(offset)) offset <- rep.int(0, n)
+
+  m <- nlevels(y) #num. thresholds
+
+  aliased_X <- !colnames(x) %in% colnames(make_full_rank(x, with.intercept = TRUE))
+
+  x_ <- x[, !aliased_X, drop = FALSE]
+  y_ <- as.integer(y)
+
+  no_x <- is_null(x_)
+
+  y_mat <- 1 * vapply(seq_len(m), function(j) y_ == j, logical(length(y_)))
+  y_mat0 <- y_mat[, -m, drop = FALSE]
+  y_mat1 <- y_mat[, -1L, drop = FALSE]
+
+  #Get predictors on a smaller scale
+  if (!no_x) {
+    sds <- apply(x_, 2L, sd)
+    x_ <- sweep(x_, 2L, sds, "/")
+  }
+
+  # Get predicted probabilities for all units for category y
+  get_p <- function(y, xb, a) {
+    pmax(.linkinv(c(a, Inf)[y] - xb) - .linkinv(c(-Inf, a)[y] - xb),
+         1e-16)
+  }
+
+  #Ordinal regression LL (cumsum paramaterization)
+  ll <- function(B, X, y, weights, offset, .cumsum_param = TRUE) {
+    if (no_x) {
+      a <- B
+      Xb <- offset
+    }
+    else {
+      a <- B[-seq_col(X)]
+      b <- B[seq_col(X)]
+      Xb <- offset + drop(X %*% b)
+    }
+
+    if (.cumsum_param && m > 2L) {
+      a <- c(a[1L], a[1L] + cumsum(exp(a[-1L])))
+    }
+
+    # Probability of observed outcome
+    p <- get_p(y, Xb, a)
+
+    sum(weights * log(p))
+  }
+
+  theta0 <- na.rem(coefs) * c(sds, rep.int(1, m - 1L))
+
+  # Psi function and gradient using natural parameterization
+  psi <- function(B, X, y, weights, offset = NULL) {
+    if (is_null(offset)) offset <- rep.int(0, length(y))
+
+    if (no_x) {
+      a <- B
+      Xb <- offset
+    }
+    else {
+      a <- B[-seq_col(X)]
+      b <- B[seq_col(X)]
+      Xb <- offset + drop(X %*% b)
+    }
+
+    pp <- get_p(y, Xb, a)
+
+    gj <- .mu.eta(c(a, Inf)[y] - Xb)
+    gj1 <- .mu.eta(c(-Inf, a)[y] - Xb)
+
+    .psi_a <- gj * y_mat0 - gj1 * y_mat1
+
+    if (no_x) {
+      out <- as.matrix(.psi_a) * (weights / pp)
+    }
+    else {
+      .psi_b <- X * (gj1 - gj)
+      out <- cbind(.psi_b, .psi_a) * (weights / pp)
+    }
+
+    colnames(out) <- names(B)
+    out
+  }
+
+  gr <- function(B, X, y, weights, offset = NULL) {
+    colSums(psi(B, X, y, weights, offset))
+  }
+
+  # Estimate using natural parameterization to get hessian
+  hessian <- try(optimHess(par = theta0,
+                           function(...) ll(..., .cumsum_param = FALSE),
+                           X = x_,
+                           y = y_,
+                           weights = weights,
+                           offset = offset,
+                           gr = gr,
+                           control = list(fnscale = -1)),
+                 silent = TRUE)
+
+  # If optimization fails, use numeric differentiation of gradient to get hessian
+  if (null_or_error(hessian)) {
+    hessian <- .gradient(gr, theta0,
+                         X = x_,
+                         y = y_,
+                         weights = weights,
+                         offset = offset)
+  }
+
+  if (!no_x) {
+    hessian <- hessian * tcrossprod(c(sds, rep.int(1, m - 1L)))
+  }
+
+  colnames(hessian) <- rownames(hessian) <- names(theta0)
+
+  hessian
+}
\ No newline at end of file
